@@ -17,6 +17,8 @@ from .upgrade import UpgradeAll, UpgradeSelected
 from .use_cache import UseCache
 from .autoresolve import Autoresolve
 from .skip_constraint_comments import SkipConstraintComments
+from .live_output import LiveOutput
+from .extra_index_url import ExtraIndexUrl
 
 
 class FeaturesController:
@@ -40,6 +42,8 @@ class FeaturesController:
         self.allow_unsafe = AllowUnsafe()
         self.autoresolve = Autoresolve()
         self.skip_constraint_comments = SkipConstraintComments()
+        self.live_output = LiveOutput()
+        self.extra_index_url = ExtraIndexUrl()
         self._features = [
             self.annotate_index,
             self.use_cache,
@@ -57,6 +61,8 @@ class FeaturesController:
             self.allow_unsafe,
             self.autoresolve,
             self.skip_constraint_comments,
+            self.live_output,
+            self.extra_index_url,
         ]
 
     def bind(self, command):
@@ -81,6 +87,7 @@ class FeaturesController:
         options.extend(self.upgrade_all.pin_options())
         options.extend(self.upgrade_selected.pin_options())
         options.extend(self.annotate_index.pin_options())
+        options.extend(self.extra_index_url.pin_options())
         return options
 
     def compose_input_file_path(self, basename):
@@ -148,3 +155,7 @@ class FeaturesController:
     def process_dependency_comments(self, comment):
         """Process comments of locked dependency (e.g. # via xxx)."""
         return self.skip_constraint_comments.process_dependency_comments(comment)
+
+    def pipe_arguments(self):
+        """Values for stdout and stderr arguments to subprocess.Popen."""
+        return self.live_output.pipe_arguments()
